/* This work is part of OpenLDAP Software <http://www.openldap.org/>.
 *
 * Copyright 1998-2020 The OpenLDAP Foundation.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted only as authorized by the OpenLDAP
 * Public License.
 *
 * A copy of this license is available in the file LICENSE in the
 * top-level directory of the distribution or, alternatively, at
 * <http://www.OpenLDAP.org/license.html>.
 */

static const char copyright[] =
"Copyright 1998-2020 The OpenLDAP Foundation.  All rights reserved.\n"
"COPYING RESTRICTIONS APPLY\n";

 const char __Version[] =
"@(#) $OpenLDAP: ldapsearch 2.4.49 (" __DATE__ " " __TIME__ ") $\n"
"\tclement@kptn-centos6:/home/clement/build/BUILD/openldap-2.4.49/clients/tools\n";

